@@ -111,8 +111,8 @@ def not_in_draft_scheme(concept):
 
 class ConceptOAIPMHRecordAdapter(oai.ArkOAIPMHRecordAdapter):
     """OAI-PMH adapter for ConceptScheme entity type."""
-    __select__ = (oai.ArkOAIPMHRecordAdapter.__select__ & is_instance('Concept') &
-                  score_entity(not_in_draft_scheme))
+    __select__ = (oai.ArkOAIPMHRecordAdapter.__select__ & is_instance('Concept')
+                  & score_entity(not_in_draft_scheme))
     metadata_formats = {'rdf': (oai.RDF_METADATAFORMAT, 'primary.rdf')}
 
     @classmethod
