@@ -102,6 +102,9 @@ class MyValueGenerator(ValueGenerator):
             ''.join(random.sample('qwertyuvckj87932141', 10)),
         ]).decode('ascii')
 
+    def generate_ArkNameAssigningAuthority_what(self, entity, index):
+        return int(''.join(random.sample('0123456789', 5)))
+
 
 class AutomaticWebTest(testlib.AutomaticWebTest):
     configcls = PostgresApptestConfiguration
