@@ -116,9 +116,8 @@ class SEDAExportTC(CubicWebTC):
             results = root.xpath('//*[@name="TransferringAgencyArchiveIdentifier"]')
             self.assertEqual(len(results), 1)
             tag = results[0]
-            # containing an empty rng:value tag.
-            value = tag.find('rng:value', namespaces=root.nsmap)
-            self.assertEqual(value.text, '')
+            # there should be no rng:value tag.
+            self.assertIsNone(tag.find('rng:value', namespaces=root.nsmap))
 
     def test_TransferringAgencyArchiveIdentifier_present_xsd(self):
         with self.admin_access.cnx() as cnx:
@@ -150,6 +149,7 @@ class CloneImportTC(CubicWebTC):
                                                                          user_annotation=u'plop')
             self.transfer_eid = transfer.eid
             self.unit_eid = unit.eid
+            self.unit_alt_seq_eid = unit_alt_seq.eid
             cnx.commit()
 
     def test_import_one_entity(self):
@@ -164,6 +164,54 @@ class CloneImportTC(CubicWebTC):
             rset = req.execute('Any X WHERE X seda_archive_unit P, P ark %(ark)s',
                                {'ark': ark})
             self.assertTrue(rset)
+            imported_unit = rset.one()
+            self.assertNotEqual(req.entity_from_eid(self.unit_eid).ark,
+                                imported_unit.ark)
+            # Make sure archive unit's ARK is qualified w.r.t. its parent
+            # archive transfer's ARK.
+            self.assertTrue(imported_unit.ark.startswith(ark), imported_unit)
+
+    def test_create_nested_archive_unit(self):
+        with self.admin_access.cnx() as cnx:
+            unit_alt_seq = cnx.entity_from_eid(self.unit_alt_seq_eid)
+            unit, _, _ = testutils.create_archive_unit(
+                unit_alt_seq, cnx=cnx,
+                ark_naa=None,
+                user_cardinality=u'1',
+                user_annotation=u'nested')
+            cnx.commit()
+            self.assertTrue(unit.ark)
+            self.assertFalse(unit.ark_naa)
+            parent = cnx.entity_from_eid(self.unit_eid)
+            # Nested archive unit has a qualified ARK from its parent archive
+            # unit.
+            self.assertTrue(unit.ark.startswith(parent.ark), unit.ark)
+
+    def test_clone_with_nested_archive_units(self):
+        with self.admin_access.cnx() as cnx:
+            transfer = cnx.entity_from_eid(self.transfer_eid)
+            _, _, unit_alt_seq = testutils.create_archive_unit(
+                transfer, cnx=cnx,
+                ark_naa=None,
+                user_cardinality=u'1',
+                user_annotation=u'top-level')
+            cnx.commit()
+            assert transfer.reverse_seda_archive_unit
+            testutils.create_archive_unit(
+                unit_alt_seq, cnx=cnx,
+                ark_naa=None,
+                user_cardinality=u'1',
+                user_annotation=u'nested')
+            cnx.commit()
+            rset = cnx.execute('Any X,Y WHERE X seda_archive_unit Y')
+            self.assertEqual(len(rset), 2, rset)
+            transfer.cw_adapt_to('IWorkflowable').fire_transition(u'publish')
+            cnx.commit()
+            testutils.setup_profile(cnx, title=u'Clone',
+                                    new_version_of=transfer)
+            cnx.commit()
+            rset = cnx.execute('Any X,Y WHERE X seda_archive_unit Y')
+            self.assertEqual(len(rset), 4, rset)
 
 
 if __name__ == '__main__':
