@@ -35,6 +35,7 @@ from cubicweb.devtools.testlib import CubicWebTC
 from cubicweb_skos.rdfio import default_graph
 
 from cubicweb_saem_ref.views.widgets import process_incomplete_date
+from cubicweb_saem_ref.views.authorityrecord import SortableListViewMixin
 
 import testutils
 
@@ -625,5 +626,107 @@ class TimelineViewsTC(CubicWebTC):
                                    ar1.view('incontext', w=None)])
 
 
+class BaseViewsTC(CubicWebTC):
+    """Test for non-business views."""
+    configcls = PostgresApptestConfiguration
+
+    def expected_notfound_html(self, etype, addlink=False):
+        parts = [
+            '<div class="searchMessage">No entity of type &quot;{}&quot; yet.'.format(etype)
+        ]
+        if addlink:
+            parts.append(
+                ' <a href="http://testing.fr/cubicweb/add/{}">Create one?</a>'.format(etype)
+            )
+        parts.append('</div>')
+        return ''.join(parts)
+
+    def test_noresult_sedalib(self):
+        with self.admin_access.web_request() as req:
+            result = self.app_handle_request(req, path='/sedalib')
+            self.assertIn(self.expected_notfound_html('SEDAArchiveUnit', True), result)
+        with self.new_access('anon').web_request() as req:
+            result = self.app_handle_request(req, path='/sedalib')
+            self.assertIn(self.expected_notfound_html('SEDAArchiveUnit'), result)
+
+    def test_no_notfound_when_no_entity(self):
+        """Check that we do not get 404 at /<etype> when no entity of <etype>
+        exists yet.
+        """
+        with self.admin_access.web_request() as req:
+            # Request /bookmark, usually there's none on a fresh instance.
+            result = self.app_handle_request(req, path='/bookmark')
+            self.assertIn(self.expected_notfound_html('Bookmark', True), result)
+        with self.new_access('anon').web_request() as req:
+            result = self.app_handle_request(req, path='/bookmark')
+            self.assertIn(self.expected_notfound_html('Bookmark'), result)
+
+    def test_true_404(self):
+        """Check 404 is returned on unknown entity type."""
+        with self.admin_access.web_request() as req:
+            self.app_handle_request(req, path='/zorglub')
+            self.assertEqual(req.status_out, 404)
+
+
+class SortableListViewMixinTC(CubicWebTC):
+
+    configcls = PostgresApptestConfiguration
+
+    class FakeListView(object):
+
+        @staticmethod
+        def related_rset(entity):
+            return entity.related('mandate_agent', role='object')
+
+    class SortableFakeListView(SortableListViewMixin, FakeListView):
+        pass
+
+    def test_related_rset_sorted_by_index(self):
+        with self.admin_access.cnx() as cnx:
+            arecord = testutils.authority_record(cnx, u'record')
+
+            m1 = cnx.create_entity('Mandate', term=u'1', mandate_agent=arecord)
+            m2 = cnx.create_entity('Mandate', term=u'2', mandate_agent=arecord)
+            m3 = cnx.create_entity('Mandate', term=u'3', mandate_agent=arecord)
+            cnx.commit()
+            fake_view = self.SortableFakeListView()
+            expected = [m1.eid, m2.eid, m3.eid]
+            actual = [e.eid for e in fake_view.related_rset(arecord).entities()]
+            self.assertEqual(expected, actual)
+
+            m1.cw_set(index=2)
+            m2.cw_set(index=3)
+            m3.cw_set(index=1)
+            cnx.commit()
+            expected = [m3.eid, m1.eid, m2.eid]
+            actual = [e.eid for e in fake_view.related_rset(arecord).entities()]
+            self.assertEqual(expected, actual)
+
+
+class SortableAjaxControllerTC(CubicWebTC):
+
+    configcls = PostgresApptestConfiguration
+
+    def setup_database(self):
+        with self.admin_access.cnx() as cnx:
+            arecord = testutils.authority_record(cnx, u'record')
+
+            self.eid0 = cnx.create_entity('Mandate', term=u'1', mandate_agent=arecord).eid
+            self.eid1 = cnx.create_entity('Mandate', term=u'2', mandate_agent=arecord).eid
+            self.eid2 = cnx.create_entity('Mandate', term=u'3', mandate_agent=arecord).eid
+            self.eids = [self.eid0, self.eid1, self.eid2]
+            cnx.commit()
+
+    def test_sort_relation_targets_sorts_sortable(self):
+        sorted_eids = [str(eid) for eid in (self.eid1, self.eid0, self.eid2)]
+        with self.remote_calling('sort_relation_targets', 'mandate_agent', sorted_eids) as (_, req):
+            indexes = [req.entity_from_eid(eid).index for eid in self.eids]
+            self.assertEqual([1, 0, 2], indexes)
+        sorted_eids = [str(eid) for eid in (self.eid2, self.eid0, self.eid1)]
+        with self.remote_calling('sort_relation_targets', 'mandate_agent', sorted_eids) as (_, req):
+            indexes = [req.entity_from_eid(eid).index for eid in self.eids]
+            self.assertEqual([1, 2, 0], indexes)
+
+
 if __name__ == '__main__':
     unittest.main()
